@@ -1,4 +1,3 @@
-
 """
 """
 
@@ -8,8 +7,7 @@ beziers = {}
 
 
 def pascal_row(n):
-    """ Returns n-th row of Pascal's triangle
-    """
+    """Returns n-th row of Pascal's triangle"""
     result = [1]
     x, numerator = 1, n
     for denominator in range(1, n // 2 + 1):
@@ -25,8 +23,8 @@ def pascal_row(n):
 
 
 def make_bezier(n):
-    """ Bezier curves:
-        http://en.wikipedia.org/wiki/B%C3%A9zier_curve#Generalization
+    """Bezier curves:
+    http://en.wikipedia.org/wiki/B%C3%A9zier_curve#Generalization
     """
     try:
         return beziers[n]
@@ -36,8 +34,9 @@ def make_bezier(n):
         for t in tsequence:
             tpowers = (t ** i for i in range(n))
             upowers = ((1 - t) ** i for i in range(n - 1, -1, -1))
-            coefs = [c * a * b for c, a, b in zip(combinations,
-                                                  tpowers, upowers)]
+            coefs = [
+                c * a * b for c, a, b in zip(combinations, tpowers, upowers)
+            ]
             result.append(coefs)
         beziers[n] = result
         return result
